emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 95ee5477e16: ; * src/lread.c (read0, skip_lazy_string): Fix com


From: Eli Zaretskii
Subject: emacs-29 95ee5477e16: ; * src/lread.c (read0, skip_lazy_string): Fix commentary again.
Date: Fri, 26 May 2023 08:11:30 -0400 (EDT)

branch: emacs-29
commit 95ee5477e1615e07e49e924deda6e5c01efc25f0
Author: Eli Zaretskii <eliz@gnu.org>
Commit: Eli Zaretskii <eliz@gnu.org>

    ; * src/lread.c (read0, skip_lazy_string): Fix commentary again.
---
 src/lread.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/lread.c b/src/lread.c
index f8ee4e63e23..c9df72a7306 100644
--- a/src/lread.c
+++ b/src/lread.c
@@ -3401,7 +3401,7 @@ read_bool_vector (Lisp_Object readcharfun)
 
 /* Skip (and optionally remember) a lazily-loaded string
    preceded by "#@".  Return true if this was a normal skip,
-   false if we read #@00 (which skips to EOB).  */
+   false if we read #@00 (which skips to EOB/EOF).  */
 static bool
 skip_lazy_string (Lisp_Object readcharfun)
 {
@@ -3938,7 +3938,7 @@ read0 (Lisp_Object readcharfun, bool locate_syms)
               and function definitions that can be loaded lazily.  */
            if (skip_lazy_string (readcharfun))
              goto read_obj;
-           obj = Qnil;       /* #@00 skips to EOB and yields nil.  */
+           obj = Qnil;       /* #@00 skips to EOB/EOF and yields nil.  */
            break;
 
          case '$':



reply via email to

[Prev in Thread] Current Thread [Next in Thread]